#
# spec file for package googletest
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libgtest0
Name:           googletest
Version:        1.7.0
Release:        12.5
Summary:        Google C++ Testing Framework
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://github.com/google/googletest
Source0:        https://github.com/google/googletest/archive/release-%{version}.tar.gz
#PATCH-FIX-UPSTREAM marguerite@opensuse.org Google thinks `make install`
#is dangerous, but I don't think so.
Patch0:         googletest-enable-make-install.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  python
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Google\'s framework for writing C++ tests on a variety of platforms
(Linux, Mac OS X, Windows, Cygwin, Windows CE, and Symbian).
Based on the xUnit architecture. Supports automatic test discovery,
a rich set of assertions, user-defined assertions, death tests,
fatal and non-fatal failures, value- and type-parameterized tests,
various options for running the tests, and XML test report generation.

%package	-n %{libname}
Summary:        Google C++ Testing Framework
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description	-n %{libname}
Google\'s framework for writing C++ tests on a variety of platforms
(Linux, Mac OS X, Windows, Cygwin, Windows CE, and Symbian).
Based on the xUnit architecture. Supports automatic test discovery,
a rich set of assertions, user-defined assertions, death tests,
fatal and non-fatal failures, value- and type-parameterized tests,
various options for running the tests, and XML test report generation.

%package        devel
Summary:        Development files for googletest
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use googletest.

%prep
%setup -q -n %{name}-release-%{version}
%patch0 -p1

%build
autoreconf -fiv
%configure \
	--enable-static=no
make %{?_smp_mflags}

%if 0%{?suse_version} > 1310
%check
make check %{?_smp_mflags}
%endif

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
mkdir -p %{buildroot}%{_bindir}
install -m 755 scripts/gtest-config %{buildroot}%{_bindir}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-, root, root)
%doc README LICENSE CONTRIBUTORS CHANGES
%{_libdir}/libgtest.so.0
%{_libdir}/libgtest.so.0.0.0
%{_libdir}/libgtest_main.so.0
%{_libdir}/libgtest_main.so.0.0.0

%files devel
%defattr(-, root, root)
%{_bindir}/gtest-config
%{_includedir}/gtest
%{_libdir}/libgtest.so
%{_libdir}/libgtest_main.so
%{_datadir}/aclocal/gtest.m4

%changelog
* Thu Aug 20 2015 mpluskal@suse.com
- Update project and source url (now on github)
- Change library name, provides obsoletes should not be necessary
  as no released binary should link against it
* Sat Feb 28 2015 mpluskal@suse.com
- Correct typo in library name
* Fri Feb 27 2015 mpluskal@suse.com
- Use source url
- Package libraries as libgoogletest0
- Run tests when building
* Sun Jul  6 2014 i@marguerite.su
- add patch: googletest-enable-make-install.patch
  * use standard procedure to install googletest.
- add scripts/gtest-config to installation
  * used by many programs to find gtest CFLAGS and etc.
- install shared libraries for sles too
* Mon Nov 11 2013 i@marguerite.su
- update version 1.7.0
  * New feature: death tests are supported on OpenBSD and in iOS
    simulator now.
  * New feature: Google Test now implements a protocol to allow
    a test runner to detect that a test program has exited
    prematurely and report it as a failure (before it would be
    falsely reported as a success if the exit code is 0).
  * New feature: Test::RecordProperty() can now be used outside of the
    lifespan of a test method, in which case it will be attributed to
    the current test case or the test program in the XML report.
  * New feature (potentially breaking): --gtest_list_tests now prints
    the type parameters and value parameters for each test.
  * Improvement: char pointers and char arrays are now escaped properly
    in failure messages.
  * Improvement: failure summary in XML reports now includes file and
    line information.
  * Improvement: the <testsuites> XML element now has a timestamp attribute.
  * Improvement: When --gtest_filter is specified, XML report now doesn't
    contain information about tests that are filtered out.
  * Fixed the bug where long --gtest_filter flag values are truncated in
    death tests.
  * Potentially breaking change: RUN_ALL_TESTS() is now implemented as a
    function instead of a macro in order to work better with Clang.
  * Compatibility fixes with C++ 11 and various platforms.
  * Bug/warning fixes.
* Sun Aug 12 2012 i@marguerite.su
- rename.
* Sun Aug 12 2012 i@marguerite.su
- force sles build static libraries, else a lot of inner test can't build.
* Sun Aug 12 2012 i@marguerite.su
- further clean spec.
- enable build shared libraries.
* Tue Aug  9 2011 tiwai@suse.de
- Add missing Group to gtest-devel
- Add missing BuildRoot (for building with older distros)
- Clean up spec file
* Sat Jul  9 2011 ftake@geeko.jp
- Initial import
  * Upstream version: 1.6.0
